@@ -4,8 +4,8 @@ weighted_variance <- function(x, w) {
   x[is.na(w)] <- NA
   w[is.na(x)] <- NA
 
-  w <- na.omit(w)
-  x <- na.omit(x)
+  w <- stats::na.omit(w)
+  x <- stats::na.omit(x)
 
   xbar <- sum(w * x) / sum(w)
   sum(w * ((x - xbar)^2)) / (sum(w) - 1)
